%+=% wraps base::list2env()

env %+=% x

Arguments

env

(environment, string) An environment or name of an environment

x

(list) A named list with the names serving as the object name to add to env and the values the object definitions/contents for each object.

Value

The target environment, invisibly

See also

Other Chapter 2 - Environment Integrity: %-=%(), %must.have%(), check.env()