refer.to is a convenience function for referring to an environment. It is a wrapper for as.environment that allows for the use of character strings and environments as arguments.

refer.to(x)

Arguments

x

An unquoted name of an environment or attached space (i.e., found in the output of search())

Value

Invisibly, the environment if it exists or an error message

See also

Other Chapter 1 - Environment Processing: copy_obj(), load_unloaded(), save_image()