snippets_toc creates a table of contents of snippet code sections.

snippets_toc(doc)

Arguments

doc

The path to a document containing code sections created via make.snippet()

Value

Invisibly, a listing of snippet code sections for the document provided

Note

An active session must be required to use this file if doc is NULL

See also

Other Chapter 3 - Workflow Management: make.snippet(), read.snippet()