%must.have% sets an attribute in the environment given by env with the name(s) of the object(s) that the environment must have. Verification is done via check.env.
env %must.have% x(object) An environment or name of an environment
(string[]) A vector or strings containing the object names that env must have when checked. Use the !! operator when passing a vector or list. Each string beginning with "-" or "!" will remove object names the target environment must have.
The names of the objects that env must have