%+=% wraps base::list2env()
env %+=% x(environment, string) An environment or name of an environment
(list) A named list with the names serving as the object name to add to env and the values the object definitions/contents for each object.
The target environment, invisibly
Other Chapter 2 - Environment Integrity:
%-=%(),
%must.have%(),
check.env()