refer.to is a convenience function for referring to an environment. It is a wrapper for as.environment that allows for the use of character strings and environments as arguments.
refer.to(x)An unquoted name of an environment or attached space (i.e., found in the output of search())
Invisibly, the environment if it exists or an error message
Other Chapter 1 - Environment Processing:
copy_obj(),
load_unloaded(),
save_image()