snippets_toc creates a table of contents of snippet code sections.
snippets_toc(doc)The path to a document containing code sections created via make.snippet()
Invisibly, a listing of snippet code sections for the document provided
An active session must be required to use this file if doc is NULL
Other Chapter 3 - Workflow Management:
make.snippet(),
read.snippet()